@@ -26,6 +26,8 @@ Contact: yuvraaj@gmail.com
 #include "GVApi.h"
 #include <QObject>
 
+// Forward declarations
+class MainWindow;
 class InboxModel;
 
 class GVInbox : public QObject
@@ -33,7 +35,7 @@ class GVInbox : public QObject
     Q_OBJECT
 
 public:
-    GVInbox (GVApi &gref, QObject *parent = 0);
+    GVInbox (MainWindow *parent = 0);
     ~GVInbox(void);
 
     void deinitModel ();
@@ -51,9 +53,6 @@ signals:
     void textANumber (const QString &strNumber,
                       const QString &strNameLink = QString ());
 
-    //! Emitted when we identify a voicemail link
-    void retrieveVoicemail (const QString &strVmailLink);
-
     //! Emitted when the Inbox AbstractModel is created
     void setInboxModel(QAbstractItemModel *model);
 
@@ -79,12 +78,14 @@ public slots:
 
     void onSigDeleteInboxEntry(const QString &id);
 
+    void cleanupAfterInboxDone(AsyncTaskToken *token);
+
 private slots:
-    void oneInboxEntry (const GVInboxEntry &hevent);
-    void getInboxDone (AsyncTaskToken *token);
-    void onInboxEntryMarked (AsyncTaskToken *token);
-    void onInboxEntryDeleted (AsyncTaskToken *token);
-    void onCheckRecentCompleted(AsyncTaskToken *token);
+    void oneInboxEntry (AsyncTaskToken *token, const GVInboxEntry &hevent);
+    void getInboxDone ();
+    void onInboxEntryMarked ();
+    void onInboxEntryDeleted ();
+    void onCheckRecentCompleted();
 
 private:
     void prepView ();
@@ -93,8 +94,6 @@ private:
     void getTrash();
 
 private:
-    GVApi          &gvApi;
-
     QDateTime       dateWaterLevel;
     bool            passedWaterLevel;
 
